=== modified file 'drizzled/dynamic_array.h'
--- drizzled/dynamic_array.h	2010-02-04 08:14:46 +0000
+++ drizzled/dynamic_array.h	2011-02-23 13:15:31 +0000
@@ -29,9 +29,15 @@
 typedef struct st_dynamic_array
 {
   unsigned char *buffer;
-  size_t elements,max_element;
+  size_t elements;
+  size_t max_element;
   uint32_t alloc_increment;
   uint32_t size_of_element;
+
+  size_t size() const
+  {
+    return elements;
+  }
 } DYNAMIC_ARRAY;
 
 #define my_init_dynamic_array(A,B,C,D) init_dynamic_array2(A,B,NULL,C,D)

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2011-02-23 12:43:31 +0000
+++ drizzled/sql_base.cc	2011-02-23 13:15:31 +0000
@@ -3310,7 +3310,7 @@
           Because of this we have to update the element count also for this
           list after expanding the '*' entry.
         */
-        sum_func_list->elements+= fields.size() - elem;
+        sum_func_list->set_size(sum_func_list->size() + fields.size() - elem);
       }
       wild_num--;
     }

=== modified file 'drizzled/sql_list.h'
--- drizzled/sql_list.h	2011-02-23 12:43:31 +0000
+++ drizzled/sql_list.h	2011-02-23 13:15:31 +0000
@@ -112,8 +112,8 @@
 {
 protected:
   list_node *first,**last;
+  uint32_t elements;
 public:
-  uint32_t elements;
 
   inline void clear() { elements=0; first= &end_of_list; last=&first;}
   inline base_list() { clear(); }
@@ -403,6 +403,11 @@
   {
     return elements;
   }
+
+  void set_size(size_t v)
+  {
+    elements = v;
+  }
 };
 
 

=== modified file 'drizzled/sql_select.cc'
--- drizzled/sql_select.cc	2011-02-22 23:20:59 +0000
+++ drizzled/sql_select.cc	2011-02-23 13:15:31 +0000
@@ -146,8 +146,8 @@
 		      select_lex->with_wild,
                       select_lex->item_list,
 		      select_lex->where,
-		      select_lex->order_list.elements +
-		      select_lex->group_list.elements,
+		      select_lex->order_list.size() +
+		      select_lex->group_list.size(),
 		      (Order*) select_lex->order_list.first,
 		      (Order*) select_lex->group_list.first,
 		      select_lex->having,
@@ -226,7 +226,7 @@
     */
     if (ref_pointer_array && !ref->found_in_select_list)
     {
-      int el= all_fields.elements;
+      int el= all_fields.size();
       ref_pointer_array[el]= item;
       /* Add the field item to the select list of the current select. */
       all_fields.push_front(item);
@@ -641,11 +641,11 @@
       (e.g. if there is a key(a,b,c) but only b < 5 (or a=2 and c < 3) is
       used in the query, we drop the partial key parts from consideration).
   */
-  if (keyuse->elements)
+  if (keyuse->size())
   {
     optimizer::KeyUse key_end,*prev,*save_pos,*use;
 
-    internal::my_qsort(keyuse->buffer,keyuse->elements,sizeof(optimizer::KeyUse),
+    internal::my_qsort(keyuse->buffer,keyuse->size(),sizeof(optimizer::KeyUse),
                        (qsort_cmp) sort_keyuse);
 
     memset(&key_end, 0, sizeof(key_end)); /* Add for easy testing */
@@ -657,7 +657,7 @@
     {
       uint32_t i;
 
-      for (i= 0; i < keyuse->elements-1; i++, use++)
+      for (i= 0; i < keyuse->size()-1; i++, use++)
       {
         if (! use->getUsedTables() && use->getOptimizeFlags() != KEY_OPTIMIZE_REF_OR_NULL)
           use->getTable()->const_key_parts[use->getKey()]|= use->getKeypartMap();
@@ -700,7 +700,7 @@
                                                   0, 
                                                   optimizer::KeyUse*);
 
-  for (end= keyuse+ keyuse_array->elements ; keyuse < end ; keyuse++)
+  for (end= keyuse+ keyuse_array->size() ; keyuse < end ; keyuse++)
   {
     table_map map;
     /*
@@ -775,7 +775,7 @@
   else
     return;
 
-  if (indexed_fields.elements == 0)
+  if (indexed_fields.size() == 0)
     return;
 
   /* Intersect the keys of all group fields. */
@@ -1880,7 +1880,7 @@
      */
     if (check_equality(session, cond, &cond_equal, &eq_list))
     {
-      int n= cond_equal.current_level.elements + eq_list.elements;
+      int n= cond_equal.current_level.size() + eq_list.size();
       if (n == 0)
         return new Item_int((int64_t) 1,1);
       else if (n == 1)
@@ -2281,7 +2281,7 @@
       }
     }
     if (cond->type() == Item::COND_ITEM &&
-        !((Item_cond*)cond)->argument_list()->elements)
+        !((Item_cond*)cond)->argument_list()->size())
       cond= new Item_int((int32_t)cond->val_bool());
 
   }
@@ -2464,7 +2464,7 @@
       if (item->name == in_additional_cond)
       {
 	li.remove();
-	if (cnd->argument_list()->elements == 1)
+	if (cnd->argument_list()->size() == 1)
 	  return cnd->argument_list()->head();
 	return conds;
       }
@@ -2655,7 +2655,7 @@
       join->cur_embedding_map |= next_emb->getNestedJoin()->nj_map;
     }
 
-    if (next_emb->getNestedJoin()->join_list.elements !=
+    if (next_emb->getNestedJoin()->join_list.size() !=
         next_emb->getNestedJoin()->counter_)
       break;
 
@@ -2762,10 +2762,10 @@
     if (should_fix_fields)
       cond->update_used_tables();
 
-    if (! ((Item_cond*) cond)->argument_list()->elements || *cond_value != Item::COND_OK)
+    if (! ((Item_cond*) cond)->argument_list()->size() || *cond_value != Item::COND_OK)
       return (COND*) NULL;
 
-    if (((Item_cond*) cond)->argument_list()->elements == 1)
+    if (((Item_cond*) cond)->argument_list()->size() == 1)
     {						
       /* Argument list contains only one element, so reduce it so a single item, then remove list */
       item= ((Item_cond*) cond)->argument_list()->head();
@@ -4067,7 +4067,7 @@
         if (fix)
           new_cond->argument_list()->push_back(fix);
       }
-      switch (new_cond->argument_list()->elements) 
+      switch (new_cond->argument_list()->size()) 
       {
         case 0:
           return (COND*) 0;			// Always true
@@ -5363,7 +5363,7 @@
   if (order_item->type() == Item::INT_ITEM && order_item->basic_const_item())
   {						/* Order by position */
     uint32_t count= (uint32_t) order_item->val_int();
-    if (!count || count > fields.elements)
+    if (!count || count > fields.size())
     {
       my_error(ER_BAD_FIELD_ERROR, MYF(0),
                order_item->full_name(), session->where());
@@ -5465,7 +5465,7 @@
        session->is_fatal_error))
     return true; /* Wrong field. */
 
-  uint32_t el= all_fields.elements;
+  uint32_t el= all_fields.size();
   all_fields.push_front(order_item); /* Add new field to field list. */
   ref_pointer_array[el]= order_item;
   order->item= ref_pointer_array + el;
@@ -5534,7 +5534,7 @@
   if (!order)
     return 0;				/* Everything is ok */
 
-  uint32_t org_fields=all_fields.elements;
+  uint32_t org_fields=all_fields.size();
 
   session->setWhere("group statement");
   for (ord= order; ord; ord= ord->next)
@@ -5607,7 +5607,7 @@
       cur_pos_in_select_list++;
     }
   }
-  if (org_fields != all_fields.elements)
+  if (org_fields != all_fields.size())
     *hidden_group_fields=1;			// group fields is not used
   return 0;
 }
@@ -5750,7 +5750,7 @@
   int idx= -1,i;
   Cached_item *buff;
 
-  for (i=(int) list.elements-1 ; (buff=li++) ; i--)
+  for (i=(int) list.size()-1 ; (buff=li++) ; i--)
   {
     if (buff->cmp())
       idx=i;
@@ -5801,7 +5801,7 @@
   res_all_fields.clear();
   List<Item>::iterator itr(res_all_fields.begin());
   List<Item> extra_funcs;
-  uint32_t i, border= all_fields.elements - elements;
+  uint32_t i, border= all_fields.size() - elements;
 
   if (param->field_count &&
       !(copy=param->copy_field= new CopyField[param->field_count]))
@@ -5893,7 +5893,7 @@
         goto err;
     }
     res_all_fields.push_back(pos);
-    ref_pointer_array[((i < border)? all_fields.elements-i-1 : i-border)]=
+    ref_pointer_array[((i < border)? all_fields.size()-i-1 : i-border)]=
       pos;
   }
   param->copy_field_end= copy;
@@ -5966,7 +5966,7 @@
   res_selected_fields.clear();
   res_all_fields.clear();
 
-  uint32_t i, border= all_fields.elements - elements;
+  uint32_t i, border= all_fields.size() - elements;
   for (i= 0; (item= it++); i++)
   {
     Field *field;
@@ -6005,7 +6005,7 @@
         item_field= item;
     }
     res_all_fields.push_back(item_field);
-    ref_pointer_array[((i < border)? all_fields.elements-i-1 : i-border)]=
+    ref_pointer_array[((i < border)? all_fields.size()-i-1 : i-border)]=
       item_field;
   }
 
@@ -6044,11 +6044,11 @@
   res_selected_fields.clear();
   res_all_fields.clear();
 
-  uint32_t i, border= all_fields.elements - elements;
+  uint32_t i, border= all_fields.size() - elements;
   for (i= 0; (item= it++); i++)
   {
     res_all_fields.push_back(new_item= item->get_tmp_table_item(session));
-    ref_pointer_array[((i < border)? all_fields.elements-i-1 : i-border)]=
+    ref_pointer_array[((i < border)? all_fields.size()-i-1 : i-border)]=
       new_item;
   }
 
@@ -6294,14 +6294,14 @@
   /* List is reversed => we should reverse it before using */
   List<TableList>::iterator ti(tables->begin());
   TableList **table= (TableList **)session->getMemRoot()->allocate(sizeof(TableList*) *
-                                                tables->elements);
+                                                tables->size());
   if (table == 0)
     return;  // out of memory
 
-  for (TableList **t= table + (tables->elements - 1); t >= table; t--)
+  for (TableList **t= table + (tables->size() - 1); t >= table; t--)
     *t= ti++;
-  assert(tables->elements >= 1);
-  print_table_array(session, str, table, table + tables->elements);
+  assert(tables->size() >= 1);
+  print_table_array(session, str, table, table + tables->size());
 }
 
 void Select_Lex::print(Session *session, String *str, enum_query_type query_type)
@@ -6344,7 +6344,7 @@
     from clause
     @todo support USING/FORCE/IGNORE index
   */
-  if (table_list.elements)
+  if (table_list.size())
   {
     str->append(STRING_WITH_LEN(" from "));
     /* go through join tree */
@@ -6373,7 +6373,7 @@
   }
 
   // group by & olap
-  if (group_list.elements)
+  if (group_list.size())
   {
     str->append(STRING_WITH_LEN(" group by "));
     print_order(str, (Order *) group_list.first, query_type);
@@ -6404,7 +6404,7 @@
       str->append(having_value != Item::COND_FALSE ? "1" : "0");
   }
 
-  if (order_list.elements)
+  if (order_list.size())
   {
     str->append(STRING_WITH_LEN(" order by "));
     print_order(str, (Order *) order_list.first, query_type);

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2011-02-22 00:55:58 +0000
+++ drizzled/sql_table.cc	2011-02-23 13:15:31 +0000
@@ -563,7 +563,7 @@
 
   plugin::StorageEngine *engine= plugin::StorageEngine::findByName(create_proto.engine().name());
 
-  select_field_pos= alter_info->create_list.elements - select_field_count;
+  select_field_pos= alter_info->create_list.size() - select_field_count;
   null_fields=blob_columns=0;
   max_key_length= engine->max_key_length();
 
@@ -860,8 +860,8 @@
                                        fk_key->update_opt,
                                        fk_key->match_opt);
 
-      if (fk_key->ref_columns.elements &&
-	  fk_key->ref_columns.elements != fk_key->columns.elements)
+      if (fk_key->ref_columns.size() &&
+	  fk_key->ref_columns.size() != fk_key->columns.size())
       {
         my_error(ER_WRONG_FK_DEF, MYF(0),
                  (fk_key->name.str ? fk_key->name.str :
@@ -873,7 +873,7 @@
     }
     (*key_count)++;
     tmp= engine->max_key_parts();
-    if (key->columns.elements > tmp)
+    if (key->columns.size() > tmp)
     {
       my_error(ER_TOO_MANY_KEY_PARTS,MYF(0),tmp);
       return(true);
@@ -897,13 +897,13 @@
           /* @todo issue warning message */
           /* mark that the generated key should be ignored */
           if (!key2->generated ||
-              (key->generated && key->columns.elements <
-               key2->columns.elements))
+              (key->generated && key->columns.size() <
+               key2->columns.size()))
             key->name.str= ignore_key;
           else
           {
             key2->name.str= ignore_key;
-            key_parts-= key2->columns.elements;
+            key_parts-= key2->columns.size();
             (*key_count)--;
           }
           break;
@@ -911,7 +911,7 @@
       }
     }
     if (key->name.str != ignore_key)
-      key_parts+=key->columns.elements;
+      key_parts+=key->columns.size();
     else
       (*key_count)--;
     if (key->name.str && !tmp_table && (key->type != Key::PRIMARY) &&
@@ -964,7 +964,7 @@
     if (key->generated)
       key_info->flags|= HA_GENERATED_KEY;
 
-    key_info->key_parts=(uint8_t) key->columns.elements;
+    key_info->key_parts=(uint8_t) key->columns.size();
     key_info->key_part=key_part_info;
     key_info->usable_key_parts= key_number;
     key_info->algorithm= key->key_create_info.algorithm;
@@ -1456,7 +1456,7 @@
   bool		error= true;
 
   /* Check for duplicate fields and check type of table to create */
-  if (not alter_info->create_list.elements)
+  if (not alter_info->create_list.size())
   {
     my_message(ER_TABLE_MUST_HAVE_COLUMNS, ER(ER_TABLE_MUST_HAVE_COLUMNS),
                MYF(0));
@@ -1834,7 +1834,7 @@
     */
     if (!table->table)
     {
-      if (!session->warn_list.elements)
+      if (!session->warn_list.size())
         push_warning(session, DRIZZLE_ERROR::WARN_LEVEL_ERROR,
                      ER_CHECK_NO_SUCH_TABLE, ER(ER_CHECK_NO_SUCH_TABLE));
       result_code= HA_ADMIN_CORRUPT;

=== modified file 'drizzled/sql_union.cc'
--- drizzled/sql_union.cc	2011-02-22 00:55:58 +0000
+++ drizzled/sql_union.cc	2011-02-23 13:15:31 +0000
@@ -126,7 +126,7 @@
 {
   assert(table == NULL);
   tmp_table_param.init();
-  tmp_table_param.field_count= column_types->elements;
+  tmp_table_param.field_count= column_types->size();
 
   if (! (table= create_tmp_table(session_arg, &tmp_table_param, *column_types,
                                  (Order*) NULL, is_union_distinct, 1,
@@ -279,8 +279,8 @@
                                sl->with_wild,
                                sl->where,
                                (can_skip_order_by ? 0 :
-                                sl->order_list.elements) +
-                               sl->group_list.elements,
+                                sl->order_list.size()) +
+                               sl->group_list.size(),
                                can_skip_order_by ?
                                (Order*) NULL : (Order *)sl->order_list.first,
                                (Order*) sl->group_list.first,
@@ -321,7 +321,7 @@
     }
     else
     {
-      if (types.elements != sl->item_list.elements)
+      if (types.size() != sl->item_list.size())
       {
 	my_message(ER_WRONG_NUMBER_OF_COLUMNS_IN_SELECT,
 		   ER(ER_WRONG_NUMBER_OF_COLUMNS_IN_SELECT),MYF(0));
@@ -371,7 +371,7 @@
     result_table_list.table= table= union_result->table;
 
     session_arg->getLex()->current_select= lex_select_save;
-    if (!item_list.elements)
+    if (!item_list.size())
     {
       saved_error= table->fill_item_list(&item_list);
       if (saved_error)
@@ -544,7 +544,7 @@
         saved_error= select_query(session, &fake_select_lex->ref_pointer_array,
                               &result_table_list,
                               0, item_list, NULL,
-                              global_parameters->order_list.elements,
+                              global_parameters->order_list.size(),
                               (Order*)global_parameters->order_list.first,
                               (Order*) NULL, NULL,
                               fake_select_lex->options | SELECT_NO_UNLOCK,
@@ -567,7 +567,7 @@
           saved_error= select_query(session, &fake_select_lex->ref_pointer_array,
                                 &result_table_list,
                                 0, item_list, NULL,
-                                global_parameters->order_list.elements,
+                                global_parameters->order_list.size(),
                                 (Order*)global_parameters->order_list.first,
                                 (Order*) NULL, NULL,
                                 fake_select_lex->options | SELECT_NO_UNLOCK,
@@ -626,7 +626,7 @@
       join->tables= 0;
     }
     error|= fake_select_lex->cleanup();
-    if (fake_select_lex->order_list.elements)
+    if (fake_select_lex->order_list.size())
     {
       Order *ord;
       for (ord= (Order*)fake_select_lex->order_list.first; ord; ord= ord->next)

=== modified file 'drizzled/sql_update.cc'
--- drizzled/sql_update.cc	2011-02-21 18:33:47 +0000
+++ drizzled/sql_update.cc	2011-02-23 13:15:31 +0000
@@ -204,7 +204,7 @@
     return 1;
   }
 
-  if (select_lex->inner_refs_list.elements &&
+  if (select_lex->inner_refs_list.size() &&
     fix_inner_refs(session, all_fields, select_lex, select_lex->ref_pointer_array))
   {
     DRIZZLE_UPDATE_DONE(1, 0, 0);

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2011-02-22 21:46:00 +0000
+++ drizzled/sql_yacc.yy	2011-02-23 13:15:31 +0000
@@ -3387,7 +3387,7 @@
             /* Use $2 instead of Lex->current_select as derived table will
                alter value of Lex->current_select. */
             if (!($3 || $5) && $2->embedding &&
-                !$2->embedding->getNestedJoin()->join_list.elements)
+                !$2->embedding->getNestedJoin()->join_list.size())
             {
               /* we have a derived table ($3 == NULL) but no alias,
                  Since we are nested in further parentheses so we
@@ -3537,7 +3537,7 @@
             }
             embedding= Lex->current_select->embedding;
             $$= embedding &&
-                !embedding->getNestedJoin()->join_list.elements;
+                !embedding->getNestedJoin()->join_list.size();
             /* return true if we are deeply nested */
           }
         ;

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2011-02-22 00:55:58 +0000
+++ drizzled/statement/alter_table.cc	2011-02-23 13:15:31 +0000
@@ -165,7 +165,7 @@
                      createTableMessage(),
                      first_table,
                      &alter_info,
-                     select_lex->order_list.elements,
+                     select_lex->order_list.size(),
                      (Order *) select_lex->order_list.first,
                      getSession()->getLex()->ignore);
   }
@@ -188,7 +188,7 @@
                        createTableMessage(),
                        first_table,
                        &alter_info,
-                       select_lex->order_list.elements,
+                       select_lex->order_list.size(),
                        (Order *) select_lex->order_list.first,
                        getSession()->getLex()->ignore);
     }
@@ -437,7 +437,7 @@
     }
   }
 
-  if (alter_info->alter_list.elements)
+  if (alter_info->alter_list.size())
   {
     my_error(ER_BAD_FIELD_ERROR,
              MYF(0),
@@ -446,7 +446,7 @@
     return true;
   }
 
-  if (not new_create_list.elements)
+  if (not new_create_list.size())
   {
     my_message(ER_CANT_REMOVE_ALL_FIELDS,
                ER(ER_CANT_REMOVE_ALL_FIELDS),
@@ -528,7 +528,7 @@
                                             strlen(cfield->field_name),
                                             key_part_length));
     }
-    if (key_parts.elements)
+    if (key_parts.size())
     {
       key_create_information_st key_create_info= default_key_create_info;
       Key *key;
@@ -639,7 +639,7 @@
     }
   }
 
-  if (alter_info->drop_list.elements)
+  if (alter_info->drop_list.size())
   {
     my_error(ER_CANT_DROP_FIELD_OR_KEY,
              MYF(0),
@@ -647,7 +647,7 @@
     return true;
   }
 
-  if (alter_info->alter_list.elements)
+  if (alter_info->alter_list.size())
   {
     my_error(ER_CANT_DROP_FIELD_OR_KEY,
              MYF(0),

=== modified file 'drizzled/statement/create_table.cc'
--- drizzled/statement/create_table.cc	2011-02-21 18:33:47 +0000
+++ drizzled/statement/create_table.cc	2011-02-23 13:15:31 +0000
@@ -178,7 +178,7 @@
 
   do 
   {
-    if (select_lex->item_list.elements)		// With select
+    if (select_lex->item_list.size())		// With select
     {
       Select_Lex_Unit *unit= &getSession()->getLex()->unit;
       select_result *result;

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2011-02-22 04:11:07 +0000
+++ drizzled/table.cc	2011-02-23 13:15:31 +0000
@@ -214,7 +214,7 @@
   TYPELIB *result= (TYPELIB*) mem_root->alloc_root(sizeof(TYPELIB));
   if (!result)
     return 0;
-  result->count= strings.elements;
+  result->count= strings.size();
   result->name= "";
   uint32_t nbytes= (sizeof(char*) + sizeof(uint32_t)) * (result->count + 1);
   

=== modified file 'drizzled/table/singular.cc'
--- drizzled/table/singular.cc	2011-02-22 00:51:13 +0000
+++ drizzled/table/singular.cc	2011-02-23 13:15:31 +0000
@@ -40,7 +40,7 @@
   _share(message::Table::INTERNAL),
   _has_variable_width(false)
 {
-  uint32_t field_count= field_list.elements;
+  uint32_t field_count= field_list.size();
   uint32_t blob_count= 0;
   Field **field_arg;
   CreateField *cdef;                           /* column definition */

